@@ -11,7 +11,7 @@ class FunMangaCom(Provider, Std):
     def get_chapter_index(self) -> str:
         return self._get_chapter_idx().replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
