@@ -9,7 +9,7 @@ class Hentai2ReadCom(Provider, Std):
         idx = self.re.search('.+/([^/]+)/', self.chapter)
         return '-'.join(idx.group(1).split('.'))
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}/')
 
     def get_manga_name(self) -> str:
