@@ -6,7 +6,7 @@ class RawDevArtComOld(Provider, Std):
     def get_chapter_index(self) -> str:
         return self.re.search(r'/chapter-(\d+(?:-\d+)?)', self.chapter).group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/comic/{}/')
 
     def get_manga_name(self) -> str:
